@@ -16,7 +16,11 @@ extern "C" {
 #endif
 
 #if defined(__CROSSWORKS_AVR)
-typedef unsigned char jmp_buf[24];  // R2-R19, R28-R29, PC, SP 
+#if __AVR_FLASH_SIZE > 128
+typedef unsigned char jmp_buf[25];  // R2-R19, R28-R29, PC, SP: 8M devices
+#else
+typedef unsigned char jmp_buf[24];  // R2-R19, R28-R29, PC, SP: 8K-128K devices 
+#endif
 #elif defined(__CROSSWORKS_MSP430)
 typedef unsigned jmp_buf[10];       // R4-R11, PC, SP
 #elif defined(__GNUC__)
