@@ -1,5 +1,173 @@
 #ifndef AT91SAM7_h
 #define AT91SAM7_h
+#define AIC_SMR0 (*(volatile unsigned long *)0xfffff000)
+#define AIC_SMR1 (*(volatile unsigned long *)0xfffff004)
+#define AIC_SMR2 (*(volatile unsigned long *)0xfffff008)
+#define AIC_SMR3 (*(volatile unsigned long *)0xfffff00c)
+#define AIC_SMR4 (*(volatile unsigned long *)0xfffff010)
+#define AIC_SMR5 (*(volatile unsigned long *)0xfffff014)
+#define AIC_SMR6 (*(volatile unsigned long *)0xfffff018)
+#define AIC_SMR7 (*(volatile unsigned long *)0xfffff01c)
+#define AIC_SMR8 (*(volatile unsigned long *)0xfffff020)
+#define AIC_SMR9 (*(volatile unsigned long *)0xfffff024)
+#define AIC_SMR10 (*(volatile unsigned long *)0xfffff028)
+#define AIC_SMR11 (*(volatile unsigned long *)0xfffff02c)
+#define AIC_SMR12 (*(volatile unsigned long *)0xfffff030)
+#define AIC_SMR13 (*(volatile unsigned long *)0xfffff034)
+#define AIC_SMR14 (*(volatile unsigned long *)0xfffff038)
+#define AIC_SMR15 (*(volatile unsigned long *)0xfffff03c)
+#define AIC_SMR16 (*(volatile unsigned long *)0xfffff040)
+#define AIC_SMR17 (*(volatile unsigned long *)0xfffff044)
+#define AIC_SMR18 (*(volatile unsigned long *)0xfffff048)
+#define AIC_SMR19 (*(volatile unsigned long *)0xfffff04c)
+#define AIC_SMR20 (*(volatile unsigned long *)0xfffff050)
+#define AIC_SMR21 (*(volatile unsigned long *)0xfffff054)
+#define AIC_SMR22 (*(volatile unsigned long *)0xfffff058)
+#define AIC_SMR23 (*(volatile unsigned long *)0xfffff05c)
+#define AIC_SMR24 (*(volatile unsigned long *)0xfffff060)
+#define AIC_SMR25 (*(volatile unsigned long *)0xfffff064)
+#define AIC_SMR26 (*(volatile unsigned long *)0xfffff068)
+#define AIC_SMR27 (*(volatile unsigned long *)0xfffff06c)
+#define AIC_SMR28 (*(volatile unsigned long *)0xfffff070)
+#define AIC_SMR29 (*(volatile unsigned long *)0xfffff074)
+#define AIC_SMR30 (*(volatile unsigned long *)0xfffff078)
+#define AIC_SMR31 (*(volatile unsigned long *)0xfffff07c)
+#define AIC_SVR0 (*(volatile unsigned long *)0xfffff080)
+#define AIC_SVR1 (*(volatile unsigned long *)0xfffff084)
+#define AIC_SVR2 (*(volatile unsigned long *)0xfffff088)
+#define AIC_SVR3 (*(volatile unsigned long *)0xfffff08c)
+#define AIC_SVR4 (*(volatile unsigned long *)0xfffff090)
+#define AIC_SVR5 (*(volatile unsigned long *)0xfffff094)
+#define AIC_SVR6 (*(volatile unsigned long *)0xfffff098)
+#define AIC_SVR7 (*(volatile unsigned long *)0xfffff09c)
+#define AIC_SVR8 (*(volatile unsigned long *)0xfffff0a0)
+#define AIC_SVR9 (*(volatile unsigned long *)0xfffff0a4)
+#define AIC_SVR10 (*(volatile unsigned long *)0xfffff0a8)
+#define AIC_SVR11 (*(volatile unsigned long *)0xfffff0ac)
+#define AIC_SVR12 (*(volatile unsigned long *)0xfffff0b0)
+#define AIC_SVR13 (*(volatile unsigned long *)0xfffff0b4)
+#define AIC_SVR14 (*(volatile unsigned long *)0xfffff0b8)
+#define AIC_SVR15 (*(volatile unsigned long *)0xfffff0bc)
+#define AIC_SVR16 (*(volatile unsigned long *)0xfffff0c0)
+#define AIC_SVR17 (*(volatile unsigned long *)0xfffff0c4)
+#define AIC_SVR18 (*(volatile unsigned long *)0xfffff0c8)
+#define AIC_SVR19 (*(volatile unsigned long *)0xfffff0cc)
+#define AIC_SVR20 (*(volatile unsigned long *)0xfffff0d0)
+#define AIC_SVR21 (*(volatile unsigned long *)0xfffff0d4)
+#define AIC_SVR22 (*(volatile unsigned long *)0xfffff0d8)
+#define AIC_SVR23 (*(volatile unsigned long *)0xfffff0dc)
+#define AIC_SVR24 (*(volatile unsigned long *)0xfffff0e0)
+#define AIC_SVR25 (*(volatile unsigned long *)0xfffff0e4)
+#define AIC_SVR26 (*(volatile unsigned long *)0xfffff0e8)
+#define AIC_SVR27 (*(volatile unsigned long *)0xfffff0ec)
+#define AIC_SVR28 (*(volatile unsigned long *)0xfffff0f0)
+#define AIC_SVR29 (*(volatile unsigned long *)0xfffff0f4)
+#define AIC_SVR30 (*(volatile unsigned long *)0xfffff0f8)
+#define AIC_SVR31 (*(volatile unsigned long *)0xfffff0fc)
+#define AIC_IVR (*(volatile unsigned long *)0xfffff100)
+#define AIC_FVR (*(volatile unsigned long *)0xfffff104)
+#define AIC_ISR (*(volatile unsigned long *)0xfffff108)
+#define AIC_IPR (*(volatile unsigned long *)0xfffff10c)
+#define AIC_IMR (*(volatile unsigned long *)0xfffff110)
+#define AIC_CISR (*(volatile unsigned long *)0xfffff114)
+#define AIC_IECR (*(volatile unsigned long *)0xfffff120)
+#define AIC_IDCR (*(volatile unsigned long *)0xfffff124)
+#define AIC_ICCR (*(volatile unsigned long *)0xfffff128)
+#define AIC_ISCR (*(volatile unsigned long *)0xfffff12c)
+#define AIC_EOICR (*(volatile unsigned long *)0xfffff130)
+#define AIC_SPU (*(volatile unsigned long *)0xfffff134)
+#define AIC_DEBUG (*(volatile unsigned long *)0xfffff138)
+#define AIC_FFER (*(volatile unsigned long *)0xfffff140)
+#define AIC_FFDR (*(volatile unsigned long *)0xfffff144)
+#define AIC_FFSR (*(volatile unsigned long *)0xfffff148)
+#define DBGU_CR (*(volatile unsigned long *)0xfffff200)
+#define DBGU_MR (*(volatile unsigned long *)0xfffff204)
+#define DBGU_IER (*(volatile unsigned long *)0xfffff208)
+#define DBGU_IDR (*(volatile unsigned long *)0xfffff20c)
+#define DBGU_IMR (*(volatile unsigned long *)0xfffff210)
+#define DBGU_SR (*(volatile unsigned long *)0xfffff214)
+#define DBGU_RHR (*(volatile unsigned long *)0xfffff218)
+#define DBGU_THR (*(volatile unsigned long *)0xfffff21c)
+#define DBGU_BRGR (*(volatile unsigned long *)0xfffff220)
+#define DBGU_CIDR (*(volatile unsigned long *)0xfffff240)
+#define DBGU_EXID (*(volatile unsigned long *)0xfffff244)
+#define DBGU_FNR (*(volatile unsigned long *)0xfffff248)
+#define DBGU_RPR (*(volatile unsigned long *)0xfffff300)
+#define DBGU_RCR (*(volatile unsigned long *)0xfffff304)
+#define DBGU_TPR (*(volatile unsigned long *)0xfffff308)
+#define DBGU_TCR (*(volatile unsigned long *)0xfffff30c)
+#define DBGU_RNPR (*(volatile unsigned long *)0xfffff310)
+#define DBGU_RNCR (*(volatile unsigned long *)0xfffff314)
+#define DBGU_TNPR (*(volatile unsigned long *)0xfffff318)
+#define DBGU_TNCR (*(volatile unsigned long *)0xfffff31c)
+#define DBGU_PTCR (*(volatile unsigned long *)0xfffff320)
+#define DBGU_PTSR (*(volatile unsigned long *)0xfffff324)
+#define PIOA_PER (*(volatile unsigned long *)0xfffff400)
+#define PIOA_PDR (*(volatile unsigned long *)0xfffff404)
+#define PIOA_PSR (*(volatile unsigned long *)0xfffff408)
+#define PIOA_OER (*(volatile unsigned long *)0xfffff410)
+#define PIOA_ODR (*(volatile unsigned long *)0xfffff414)
+#define PIOA_OSR (*(volatile unsigned long *)0xfffff418)
+#define PIOA_IFER (*(volatile unsigned long *)0xfffff420)
+#define PIOA_IFDR (*(volatile unsigned long *)0xfffff424)
+#define PIOA_IFSR (*(volatile unsigned long *)0xfffff428)
+#define PIOA_SODR (*(volatile unsigned long *)0xfffff430)
+#define PIOA_CODR (*(volatile unsigned long *)0xfffff434)
+#define PIOA_ODSR (*(volatile unsigned long *)0xfffff438)
+#define PIOA_PDSR (*(volatile unsigned long *)0xfffff43c)
+#define PIOA_IER (*(volatile unsigned long *)0xfffff440)
+#define PIOA_IDR (*(volatile unsigned long *)0xfffff444)
+#define PIOA_IMR (*(volatile unsigned long *)0xfffff448)
+#define PIOA_ISR (*(volatile unsigned long *)0xfffff44c)
+#define PIOA_MDER (*(volatile unsigned long *)0xfffff450)
+#define PIOA_MDDR (*(volatile unsigned long *)0xfffff454)
+#define PIOA_MDSR (*(volatile unsigned long *)0xfffff458)
+#define PIOA_PUDR (*(volatile unsigned long *)0xfffff460)
+#define PIOA_PUER (*(volatile unsigned long *)0xfffff464)
+#define PIOA_PUSR (*(volatile unsigned long *)0xfffff468)
+#define PIOA_ASR (*(volatile unsigned long *)0xfffff470)
+#define PIOA_BSR (*(volatile unsigned long *)0xfffff474)
+#define PIOA_ABSR (*(volatile unsigned long *)0xfffff478)
+#define PIOA_OWER (*(volatile unsigned long *)0xfffff4a0)
+#define PIOA_OWDR (*(volatile unsigned long *)0xfffff4a4)
+#define PIOA_OWSR (*(volatile unsigned long *)0xfffff4a8)
+#define PMC_SCER (*(volatile unsigned long *)0xfffffc00)
+#define PMC_SCDR (*(volatile unsigned long *)0xfffffc04)
+#define PMC_SCSR (*(volatile unsigned long *)0xfffffc08)
+#define PMC_PCER (*(volatile unsigned long *)0xfffffc10)
+#define PMC_PCDR (*(volatile unsigned long *)0xfffffc14)
+#define PMC_PCSR (*(volatile unsigned long *)0xfffffc18)
+#define CKGR_MOR (*(volatile unsigned long *)0xfffffc20)
+#define CKGR_MCFR (*(volatile unsigned long *)0xfffffc24)
+#define CKGR_PLLR (*(volatile unsigned long *)0xfffffc2c)
+#define PMC_MCKR (*(volatile unsigned long *)0xfffffc30)
+#define PMC_PCK0 (*(volatile unsigned long *)0xfffffc40)
+#define PMC_PCK1 (*(volatile unsigned long *)0xfffffc44)
+#define PMC_IER (*(volatile unsigned long *)0xfffffc60)
+#define PMC_IDR (*(volatile unsigned long *)0xfffffc64)
+#define PMC_SR (*(volatile unsigned long *)0xfffffc68)
+#define PMC_IMR (*(volatile unsigned long *)0xfffffc6c)
+#define RSTC_CR (*(volatile unsigned long *)0xfffffd00)
+#define RSTC_SR (*(volatile unsigned long *)0xfffffd04)
+#define RSTC_MR (*(volatile unsigned long *)0xfffffd08)
+#define RTT_MR (*(volatile unsigned long *)0xfffffd20)
+#define RTT_AR (*(volatile unsigned long *)0xfffffd24)
+#define RTT_VR (*(volatile unsigned long *)0xfffffd28)
+#define RTT_SR (*(volatile unsigned long *)0xfffffd2c)
+#define PIT_MR (*(volatile unsigned long *)0xfffffd30)
+#define PIT_SR (*(volatile unsigned long *)0xfffffd34)
+#define PIT_PIVR (*(volatile unsigned long *)0xfffffd38)
+#define PIT_PIIR (*(volatile unsigned long *)0xfffffd3c)
+#define WDT_CR (*(volatile unsigned long *)0xfffffd40)
+#define WDT_MR (*(volatile unsigned long *)0xfffffd44)
+#define WDT_SR (*(volatile unsigned long *)0xfffffd48)
+#define WREG_MR (*(volatile unsigned long *)0xfffffd60)
+#define MC_RCR (*(volatile unsigned long *)0xffffff00)
+#define MC_ASR (*(volatile unsigned long *)0xffffff04)
+#define MC_AASR (*(volatile unsigned long *)0xffffff08)
+#define MC_FMR (*(volatile unsigned long *)0xffffff60)
+#define MC_FCR (*(volatile unsigned long *)0xffffff64)
+#define MC_FSR (*(volatile unsigned long *)0xffffff68)
 #define TC0_CCR (*(volatile unsigned long *)0xfffa0000)
 #define TC0_CMR (*(volatile unsigned long *)0xfffa0004)
 #define TC0_CV (*(volatile unsigned long *)0xfffa0010)
@@ -41,15 +209,15 @@
 #define USB_ISR (*(volatile unsigned long *)0xfffb001c)
 #define USB_ICR (*(volatile unsigned long *)0xfffb0020)
 #define USB_RST_EP (*(volatile unsigned long *)0xfffb0028)
-#define USB_CSR0  (*(volatile unsigned long *)0xfffb0030)
-#define USB_CSR1  (*(volatile unsigned long *)0xfffb0034)
-#define USB_CSR2  (*(volatile unsigned long *)0xfffb0038)
-#define USB_CSR3  (*(volatile unsigned long *)0xfffb003c)
-#define USB_FDR0  (*(volatile unsigned long *)0xfffb0050)
-#define USB_FDR1  (*(volatile unsigned long *)0xfffb0054)
-#define USB_FDR2  (*(volatile unsigned long *)0xfffb0058)
-#define USB_FDR3  (*(volatile unsigned long *)0xfffb005c)
-#define USB_TXVC  (*(volatile unsigned long *)0xfffb0074)
+#define USB_CSR0 (*(volatile unsigned long *)0xfffb0030)
+#define USB_CSR1 (*(volatile unsigned long *)0xfffb0034)
+#define USB_CSR2 (*(volatile unsigned long *)0xfffb0038)
+#define USB_CSR3 (*(volatile unsigned long *)0xfffb003c)
+#define USB_FDR0 (*(volatile unsigned long *)0xfffb0050)
+#define USB_FDR1 (*(volatile unsigned long *)0xfffb0054)
+#define USB_FDR2 (*(volatile unsigned long *)0xfffb0058)
+#define USB_FDR3 (*(volatile unsigned long *)0xfffb005c)
+#define USB_TXVC (*(volatile unsigned long *)0xfffb0074)
 #define TWI_CR (*(volatile unsigned long *)0xfffb8000)
 #define TWI_MMR (*(volatile unsigned long *)0xfffb8004)
 #define TWI_IADR (*(volatile unsigned long *)0xfffb800c)
@@ -201,172 +369,4 @@
 #define SPI_TNCR (*(volatile unsigned long *)0xfffe011c)
 #define SPI_PTCR (*(volatile unsigned long *)0xfffe0120)
 #define SPI_PTSR (*(volatile unsigned long *)0xfffe0124)
-#define AIC_SMR0 (*(volatile unsigned long *)0xfffff000)
-#define AIC_SMR1 (*(volatile unsigned long *)0xfffff004)
-#define AIC_SMR2 (*(volatile unsigned long *)0xfffff008)
-#define AIC_SMR3 (*(volatile unsigned long *)0xfffff00c)
-#define AIC_SMR4 (*(volatile unsigned long *)0xfffff010)
-#define AIC_SMR5 (*(volatile unsigned long *)0xfffff014)
-#define AIC_SMR6 (*(volatile unsigned long *)0xfffff018)
-#define AIC_SMR7 (*(volatile unsigned long *)0xfffff01c)
-#define AIC_SMR8 (*(volatile unsigned long *)0xfffff020)
-#define AIC_SMR9 (*(volatile unsigned long *)0xfffff024)
-#define AIC_SMR10 (*(volatile unsigned long *)0xfffff028)
-#define AIC_SMR11 (*(volatile unsigned long *)0xfffff02c)
-#define AIC_SMR12 (*(volatile unsigned long *)0xfffff030)
-#define AIC_SMR13 (*(volatile unsigned long *)0xfffff034)
-#define AIC_SMR14 (*(volatile unsigned long *)0xfffff038)
-#define AIC_SMR15 (*(volatile unsigned long *)0xfffff03c)
-#define AIC_SMR16 (*(volatile unsigned long *)0xfffff040)
-#define AIC_SMR17 (*(volatile unsigned long *)0xfffff044)
-#define AIC_SMR18 (*(volatile unsigned long *)0xfffff048)
-#define AIC_SMR19 (*(volatile unsigned long *)0xfffff04c)
-#define AIC_SMR20 (*(volatile unsigned long *)0xfffff050)
-#define AIC_SMR21 (*(volatile unsigned long *)0xfffff054)
-#define AIC_SMR22 (*(volatile unsigned long *)0xfffff058)
-#define AIC_SMR23 (*(volatile unsigned long *)0xfffff05c)
-#define AIC_SMR24 (*(volatile unsigned long *)0xfffff060)
-#define AIC_SMR25 (*(volatile unsigned long *)0xfffff064)
-#define AIC_SMR26 (*(volatile unsigned long *)0xfffff068)
-#define AIC_SMR27 (*(volatile unsigned long *)0xfffff06c)
-#define AIC_SMR28 (*(volatile unsigned long *)0xfffff070)
-#define AIC_SMR29 (*(volatile unsigned long *)0xfffff074)
-#define AIC_SMR30 (*(volatile unsigned long *)0xfffff078)
-#define AIC_SMR31 (*(volatile unsigned long *)0xfffff07c)
-#define AIC_SVR0 (*(volatile unsigned long *)0xfffff080)
-#define AIC_SVR1 (*(volatile unsigned long *)0xfffff084)
-#define AIC_SVR2 (*(volatile unsigned long *)0xfffff088)
-#define AIC_SVR3 (*(volatile unsigned long *)0xfffff08c)
-#define AIC_SVR4 (*(volatile unsigned long *)0xfffff090)
-#define AIC_SVR5 (*(volatile unsigned long *)0xfffff094)
-#define AIC_SVR6 (*(volatile unsigned long *)0xfffff098)
-#define AIC_SVR7 (*(volatile unsigned long *)0xfffff09c)
-#define AIC_SVR8 (*(volatile unsigned long *)0xfffff0a0)
-#define AIC_SVR9 (*(volatile unsigned long *)0xfffff0a4)
-#define AIC_SVR10 (*(volatile unsigned long *)0xfffff0a8)
-#define AIC_SVR11 (*(volatile unsigned long *)0xfffff0ac)
-#define AIC_SVR12 (*(volatile unsigned long *)0xfffff0b0)
-#define AIC_SVR13 (*(volatile unsigned long *)0xfffff0b4)
-#define AIC_SVR14 (*(volatile unsigned long *)0xfffff0b8)
-#define AIC_SVR15 (*(volatile unsigned long *)0xfffff0bc)
-#define AIC_SVR16 (*(volatile unsigned long *)0xfffff0c0)
-#define AIC_SVR17 (*(volatile unsigned long *)0xfffff0c4)
-#define AIC_SVR18 (*(volatile unsigned long *)0xfffff0c8)
-#define AIC_SVR19 (*(volatile unsigned long *)0xfffff0cc)
-#define AIC_SVR20 (*(volatile unsigned long *)0xfffff0d0)
-#define AIC_SVR21 (*(volatile unsigned long *)0xfffff0d4)
-#define AIC_SVR22 (*(volatile unsigned long *)0xfffff0d8)
-#define AIC_SVR23 (*(volatile unsigned long *)0xfffff0dc)
-#define AIC_SVR24 (*(volatile unsigned long *)0xfffff0e0)
-#define AIC_SVR25 (*(volatile unsigned long *)0xfffff0e4)
-#define AIC_SVR26 (*(volatile unsigned long *)0xfffff0e8)
-#define AIC_SVR27 (*(volatile unsigned long *)0xfffff0ec)
-#define AIC_SVR28 (*(volatile unsigned long *)0xfffff0f0)
-#define AIC_SVR29 (*(volatile unsigned long *)0xfffff0f4)
-#define AIC_SVR30 (*(volatile unsigned long *)0xfffff0f8)
-#define AIC_SVR31 (*(volatile unsigned long *)0xfffff0fc)
-#define AIC_IVR (*(volatile unsigned long *)0xfffff100)
-#define AIC_FVR (*(volatile unsigned long *)0xfffff104)
-#define AIC_ISR (*(volatile unsigned long *)0xfffff108)
-#define AIC_IPR (*(volatile unsigned long *)0xfffff10c)
-#define AIC_IMR (*(volatile unsigned long *)0xfffff110)
-#define AIC_CISR (*(volatile unsigned long *)0xfffff114)
-#define AIC_IECR (*(volatile unsigned long *)0xfffff120)
-#define AIC_IDCR (*(volatile unsigned long *)0xfffff124)
-#define AIC_ICCR (*(volatile unsigned long *)0xfffff128)
-#define AIC_ISCR (*(volatile unsigned long *)0xfffff12c)
-#define AIC_EOICR (*(volatile unsigned long *)0xfffff130)
-#define AIC_SPU (*(volatile unsigned long *)0xfffff134)
-#define AIC_DCR (*(volatile unsigned long *)0xfffff138)
-#define AIC_FFER (*(volatile unsigned long *)0xfffff140)
-#define AIC_FFDR (*(volatile unsigned long *)0xfffff144)
-#define AIC_FFSR (*(volatile unsigned long *)0xfffff148)
-#define DBGU_CR (*(volatile unsigned long *)0xfffff200)
-#define DBGU_MR (*(volatile unsigned long *)0xfffff204)
-#define DBGU_IER (*(volatile unsigned long *)0xfffff208)
-#define DBGU_IDR (*(volatile unsigned long *)0xfffff20c)
-#define DBGU_IMR (*(volatile unsigned long *)0xfffff210)
-#define DBGU_SR (*(volatile unsigned long *)0xfffff214)
-#define DBGU_RHR (*(volatile unsigned long *)0xfffff218)
-#define DBGU_THR (*(volatile unsigned long *)0xfffff21c)
-#define DBGU_BRGR (*(volatile unsigned long *)0xfffff220)
-#define DBGU_CIDR (*(volatile unsigned long *)0xfffff240)
-#define DBGU_EXID (*(volatile unsigned long *)0xfffff244)
-#define DBGU_FNR (*(volatile unsigned long *)0xfffff248)
-#define DBGU_RPR (*(volatile unsigned long *)0xfffff300)
-#define DBGU_RCR (*(volatile unsigned long *)0xfffff304)
-#define DBGU_TPR (*(volatile unsigned long *)0xfffff308)
-#define DBGU_TCR (*(volatile unsigned long *)0xfffff30c)
-#define DBGU_RNPR (*(volatile unsigned long *)0xfffff310)
-#define DBGU_RNCR (*(volatile unsigned long *)0xfffff314)
-#define DBGU_TNPR (*(volatile unsigned long *)0xfffff318)
-#define DBGU_TNCR (*(volatile unsigned long *)0xfffff31c)
-#define DBGU_PTCR (*(volatile unsigned long *)0xfffff320)
-#define DBGU_PTSR (*(volatile unsigned long *)0xfffff324)
-#define PIOA_PER (*(volatile unsigned long *)0xfffff400)
-#define PIOA_PDR (*(volatile unsigned long *)0xfffff404)
-#define PIOA_PSR (*(volatile unsigned long *)0xfffff408)
-#define PIOA_OER (*(volatile unsigned long *)0xfffff410)
-#define PIOA_ODR (*(volatile unsigned long *)0xfffff414)
-#define PIOA_OSR (*(volatile unsigned long *)0xfffff418)
-#define PIOA_IFER (*(volatile unsigned long *)0xfffff420)
-#define PIOA_IFDR (*(volatile unsigned long *)0xfffff424)
-#define PIOA_IFSR (*(volatile unsigned long *)0xfffff428)
-#define PIOA_SODR (*(volatile unsigned long *)0xfffff430)
-#define PIOA_CODR (*(volatile unsigned long *)0xfffff434)
-#define PIOA_ODSR (*(volatile unsigned long *)0xfffff438)
-#define PIOA_PDSR (*(volatile unsigned long *)0xfffff43c)
-#define PIOA_IER (*(volatile unsigned long *)0xfffff440)
-#define PIOA_IDR (*(volatile unsigned long *)0xfffff444)
-#define PIOA_IMR (*(volatile unsigned long *)0xfffff448)
-#define PIOA_ISR (*(volatile unsigned long *)0xfffff44c)
-#define PIOA_MDER (*(volatile unsigned long *)0xfffff450)
-#define PIOA_MDDR (*(volatile unsigned long *)0xfffff454)
-#define PIOA_MDSR (*(volatile unsigned long *)0xfffff458)
-#define PIOA_PUDR (*(volatile unsigned long *)0xfffff460)
-#define PIOA_PUER (*(volatile unsigned long *)0xfffff464)
-#define PIOA_PUSR (*(volatile unsigned long *)0xfffff468)
-#define PIOA_ASR (*(volatile unsigned long *)0xfffff470)
-#define PIOA_BSR (*(volatile unsigned long *)0xfffff474)
-#define PIOA_ABSR (*(volatile unsigned long *)0xfffff478)
-#define PIOA_OWER (*(volatile unsigned long *)0xfffff4a0)
-#define PIOA_OWDR (*(volatile unsigned long *)0xfffff4a4)
-#define PIOA_OWSR (*(volatile unsigned long *)0xfffff4a8)
-#define PMC_SCER (*(volatile unsigned long *)0xfffffc00)
-#define PMC_SCDR (*(volatile unsigned long *)0xfffffc04)
-#define PMC_SCSR (*(volatile unsigned long *)0xfffffc08)
-#define PMC_PCER (*(volatile unsigned long *)0xfffffc10)
-#define PMC_PCDR (*(volatile unsigned long *)0xfffffc14)
-#define PMC_SCSR (*(volatile unsigned long *)0xfffffc18)
-#define CKGR_MOR (*(volatile unsigned long *)0xfffffc20)
-#define CKGR_MCFR (*(volatile unsigned long *)0xfffffc24)
-#define CKGR_PLLR (*(volatile unsigned long *)0xfffffc2c)
-#define PMC_MCKR (*(volatile unsigned long *)0xfffffc30)
-#define PMC_PCK0 (*(volatile unsigned long *)0xfffffc40)
-#define PMC_PCK1 (*(volatile unsigned long *)0xfffffc44)
-#define PMC_IER (*(volatile unsigned long *)0xfffffc60)
-#define PMC_IDR (*(volatile unsigned long *)0xfffffc64)
-#define PMC_SR (*(volatile unsigned long *)0xfffffc68)
-#define PMC_IMR (*(volatile unsigned long *)0xfffffc6c)
-#define RSTC_CR (*(volatile unsigned long *)0xfffffd00)
-#define RSTC_SR (*(volatile unsigned long *)0xfffffd04)
-#define RSTC_MR (*(volatile unsigned long *)0xfffffd08)
-#define RTT_MR (*(volatile unsigned long *)0xfffffd20)
-#define RTT_AR (*(volatile unsigned long *)0xfffffd24)
-#define RTT_VR (*(volatile unsigned long *)0xfffffd28)
-#define RTT_SR (*(volatile unsigned long *)0xfffffd2c)
-#define PIT_MR (*(volatile unsigned long *)0xfffffd30)
-#define PIT_SR (*(volatile unsigned long *)0xfffffd34)
-#define PIT_PIVR (*(volatile unsigned long *)0xfffffd38)
-#define PIT_PIIR (*(volatile unsigned long *)0xfffffd3c)
-#define WDT_CR (*(volatile unsigned long *)0xfffffd40)
-#define WDT_MR (*(volatile unsigned long *)0xfffffd44)
-#define WDT_SR (*(volatile unsigned long *)0xfffffd48)
-#define WREG_MR (*(volatile unsigned long *)0xfffffd60)
-#define MC_RCR (*(volatile unsigned long *)0xffffff00)
-#define MC_ASR (*(volatile unsigned long *)0xffffff04)
-#define MC_AASR (*(volatile unsigned long *)0xffffff08)
-#define MC_FMR (*(volatile unsigned long *)0xffffff60)
-#define MC_FCR (*(volatile unsigned long *)0xffffff64)
-#define MC_FSR (*(volatile unsigned long *)0xffffff68)
 #endif
