@@ -31,25 +31,31 @@
 #define UART2_TXD (*(volatile unsigned long *)0xfffc2000)
 #define UART2_RXD (*(volatile unsigned long *)0xfffc2000)
 #define UART2_BAL (*(volatile unsigned long *)0xfffc2000)
+#define UART2_CLCF (*(volatile unsigned long *)0xfffc2000)
+#define UART2_BBL (*(volatile unsigned long *)0xfffc2000)
 #define UART2_BAH (*(volatile unsigned long *)0xfffc2004)
 #define UART2_GER (*(volatile unsigned long *)0xfffc2004)
 #define UART2_TXF (*(volatile unsigned long *)0xfffc2004)
 #define UART2_RXF (*(volatile unsigned long *)0xfffc2004)
 #define UART2_FMD (*(volatile unsigned long *)0xfffc2004)
+#define UART2_BACF (*(volatile unsigned long *)0xfffc2004)
+#define UART2_BBH (*(volatile unsigned long *)0xfffc2004)
 #define UART2_GIR (*(volatile unsigned long *)0xfffc2008)
 #define UART2_LCR (*(volatile unsigned long *)0xfffc200c)
-#define UART2_TMCTRL (*(volatile unsigned long *)0xfffc200c)
+#define UART2_TMCR (*(volatile unsigned long *)0xfffc200c)
 #define UART2_TMST (*(volatile unsigned long *)0xfffc200c)
 #define UART2_TMD (*(volatile unsigned long *)0xfffc200c)
-#define UART2_MCTRL (*(volatile unsigned long *)0xfffc2010)
+#define UART2_BBCF (*(volatile unsigned long *)0xfffc200c)
+#define UART2_MCR (*(volatile unsigned long *)0xfffc2010)
 #define UART2_FLR (*(volatile unsigned long *)0xfffc2010)
 #define UART2_IMD (*(volatile unsigned long *)0xfffc2010)
 #define UART2_LSR (*(volatile unsigned long *)0xfffc2014)
 #define UART2_RCM (*(volatile unsigned long *)0xfffc2014)
 #define UART2_RST (*(volatile unsigned long *)0xfffc2014)
-#define UART2_ACTRL1 (*(volatile unsigned long *)0xfffc2014)
+#define UART2_ACR1 (*(volatile unsigned long *)0xfffc2014)
 #define UART2_RIE (*(volatile unsigned long *)0xfffc2018)
-#define UART2_ACTRL0 (*(volatile unsigned long *)0xfffc201c)
+#define UART2_TMIE (*(volatile unsigned long *)0xfffc2018)
+#define UART2_ACR0 (*(volatile unsigned long *)0xfffc201c)
 #define UART2_ICM (*(volatile unsigned long *)0xfffc201c)
 #define UART2_GSR (*(volatile unsigned long *)0xfffc201c)
 #define UART2_RMD (*(volatile unsigned long *)0xfffc201c)
