@@ -20,7 +20,7 @@
 
 #include "test.h"
 #include <ctl_api.h>
-#include <targets/LPC210x.h>
+#include <targets/LPC21xx.h>
 
 #define EINT1_INT 15
 
